@@ -5,8 +5,8 @@
 #' @param model See \link[lcsm]{specify_uni_lcsm}
 #' @param change_letter See \link[lcsm]{specify_uni_lcsm}
 #' @param sample.nobs Numeric, number of cases to be simulated, see \link[lcsm]{specify_uni_lcsm}
-#' @param na_pct Numeric, percentage of random missing values in the simulated dataset [0,1]
-#' @param model_param List, specifying parameter estimates for the LCS model that has been specified in the argument 'model'
+#' @param na_pct Numeric, percentage of random missing values in the simulated dataset (0 to 1)
+#' @param model_param List, specifying parameter estimates for the LCSM that has been specified in the argument 'model'
 #' \itemize{
 #' \item{\strong{\code{gamma_lx1}}}: Mean of latent true scores x (Intercept),
 #' \item{\strong{\code{sigma2_lx1}}}: Variance of latent true scores x,
@@ -20,24 +20,26 @@
 #' \item{\strong{\code{sigma_g2g3}}}: Covariance of change factors (g2 and g2),
 #' \item{\strong{\code{phi_x}}}: Autoregression of change scores x.
 #' }
+#' @param seed Set seed for data simulation, see \link[lavaan]{simulateData}
 #' @param ... Arguments to be passed on to \link[lavaan]{simulateData}
 #' @param return_lavaan_syntax Logical, if TRUE return the lavaan syntax used for simulating data. To make it look beautiful use the function \link[base]{cat}.
 #' @return tibble
 #' @export
-#' @examples # Simulate data from univariate LCS model parameters 
+#' @examples # Simulate data from univariate LCSM parameters 
 #' sim_uni_lcsm(timepoints = 10, 
 #'              model = list(alpha_constant = TRUE, beta = FALSE, phi = TRUE), 
 #'              model_param = list(gamma_lx1 = 21, 
 #'                                 sigma2_lx1 = 1.5,
 #'                                 sigma2_ux = .2, 
-#'                                 alpha_j2 = -.93,
-#'                                 sigma2_j2 = .1,
-#'                                 sigma_j2lx1 = .2),
+#'                                 alpha_g2 = -.93,
+#'                                 sigma2_g2 = .1,
+#'                                 sigma_g2lx1 = .2,
+#'                                 phi_x = .2),
 #'              return_lavaan_syntax = FALSE, 
 #'              sample.nobs = 1000,
 #'              na_pct = .3)
 #' 
-sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", change_letter = "g", sample.nobs = 500, na_pct = 0, ..., return_lavaan_syntax = FALSE){
+sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", change_letter = "g", sample.nobs = 500, na_pct = 0, seed = NULL, ..., return_lavaan_syntax = FALSE){
   
   # 1. Create lavaan syntax  ----
   # String including labels for parameters
@@ -75,7 +77,7 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
     
     # Test if all labels have been specified
     if (base::all(check_labels) == TRUE){
-      base::message("All parameter estimates for the LCS model have been specified in the argument 'model_param'.")
+      base::message("All parameter estimates for the LCSM have been specified in the argument 'model_param'.")
     } else if (base::all(check_labels) == FALSE){
       
       missing_labels <- labels[base::which(!check_labels)]
@@ -84,7 +86,7 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
       
       missing_labels_02 <- stringr::str_c(missing_labels_01, sep = "", collapse = "\n")
       
-      base::warning(paste0("The following parameters are specified in LCS model but no parameter estimates have been entered in 'model_param':\n", missing_labels_02), call. = FALSE)
+      base::warning(paste0("The following parameters are specified in the LCSM but no parameter estimates have been entered in 'model_param':\n", missing_labels_02), call. = FALSE)
     }
     
     estimates <- model_param
@@ -117,7 +119,7 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
                                          group.label = paste("G", 1:ngroups, sep = ""), 
                                          skewness = 0, 
                                          kurtosis = 0, 
-                                         seed = NULL, 
+                                         seed = seed,
                                          empirical = FALSE, 
                                          return.type = "data.frame",
                                          return.fit = FALSE,
@@ -147,9 +149,9 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
   if (return_lavaan_syntax == FALSE){
     # Return simulated data
     return(sim_data_model_ids_nas)
+    
   } else if (return_lavaan_syntax == TRUE){
     
-
       return(model_estimates)
 
   }
@@ -159,7 +161,7 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
 #' @description This function simulate data from bivariate latent change score model parameter estimates using \link[lavaan]{simulateData}.
 #' @param timepoints See \link[lcsm]{specify_bi_lcsm}
 #' @param model_x See \link[lcsm]{specify_bi_lcsm}
-#' @param model_x_param List, specifying parameter estimates for the LCS model that has been specified in the argument '\code{model_x}':
+#' @param model_x_param List, specifying parameter estimates for the LCSM that has been specified in the argument '\code{model_x}':
 #' \itemize{
 #' \item{\strong{\code{gamma_lx1}}}: Mean of latent true scores x (Intercept),
 #' \item{\strong{\code{sigma2_lx1}}}: Variance of latent true scores x,
@@ -174,7 +176,7 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
 #' \item{\strong{\code{phi_x}}}: Autoregression of change scores x.
 #' }
 #' @param model_y See \link[lcsm]{specify_bi_lcsm}
-#' @param model_y_param List, specifying parameter estimates for the LCS model that has been specified in the argument '\code{model_y}':
+#' @param model_y_param List, specifying parameter estimates for the LCSM that has been specified in the argument '\code{model_y}':
 #' \itemize{
 #' \item{\strong{\code{gamma_ly1}}}: Mean of latent true scores y (Intercept),
 #' \item{\strong{\code{sigma2_ly1}}}: Variance of latent true scores y,
@@ -210,8 +212,9 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
 #' \item{\strong{\code{xi_lag_yx}}}: Change score y (t) determined by change score x (t-1)
 #' }
 #' @param sample.nobs Numeric, number of cases to be simulated, see \link[lcsm]{specify_uni_lcsm}
-#' @param na_x_pct Numeric, percentage of random missing values in the simulated dataset [0,1]
-#' @param na_y_pct Numeric, percentage of random missing values in the simulated dataset [0,1]
+#' @param na_x_pct Numeric, percentage of random missing values in the simulated dataset (0 to 1)
+#' @param na_y_pct Numeric, percentage of random missing values in the simulated dataset (0 to 1)
+#' @param seed Set seed for data simulation, see \link[lavaan]{simulateData}
 #' @param ... Arguments to be passed on to \link[lavaan]{simulateData}
 #' @param var_x See \link[lcsm]{specify_bi_lcsm}
 #' @param var_y See \link[lcsm]{specify_bi_lcsm}
@@ -220,17 +223,17 @@ sim_uni_lcsm <- function(timepoints, model, model_param = NULL, var = "x", chang
 #' @param return_lavaan_syntax Logical, if TRUE return the lavaan syntax used for simulating data. To make it look beautiful use the function \link[base]{cat}.
 #' @return tibble
 #' @export
-#' @references Ghisletta, P., & McArdle, J. J. (2012). Latent Curve Models and Latent Change Score Models Estimated in R. Structural Equation Modeling: A Multidisciplinary Journal, 19(4), 651–682. \url{https://doi.org/10.1080/10705511.2012.713275}.
+#' @references Ghisletta, P., & McArdle, J. J. (2012). Latent Curve Models and Latent Change Score Models Estimated in R. Structural Equation Modeling: A Multidisciplinary Journal, 19(4), 651–682. \doi{10.1080/10705511.2012.713275}.
 #' 
 #' Grimm, K. J., Ram, N., & Estabrook, R. (2017). Growth Modeling—Structural Equation and Multilevel Modeling Approaches. New York: The Guilford Press.
 #' 
-#' Kievit, R. A., Brandmaier, A. M., Ziegler, G., van Harmelen, A.-L., de Mooij, S. M. M., Moutoussis, M., … Dolan, R. J. (2018). Developmental cognitive neuroscience using latent change score models: A tutorial and applications. Developmental Cognitive Neuroscience, 33, 99–117. \url{https://doi.org/10.1016/j.dcn.2017.11.007}.
+#' Kievit, R. A., Brandmaier, A. M., Ziegler, G., van Harmelen, A.-L., de Mooij, S. M. M., Moutoussis, M., … Dolan, R. J. (2018). Developmental cognitive neuroscience using latent change score models: A tutorial and applications. Developmental Cognitive Neuroscience, 33, 99–117. \doi{10.1016/j.dcn.2017.11.007}.
 #' 
-#' McArdle, J. J. (2009). Latent variable modeling of differences and changes with longitudinal data. Annual Review of Psychology, 60(1), 577–605. \url{https://doi.org/10.1146/annurev.psych.60.110707.163612}.
+#' McArdle, J. J. (2009). Latent variable modeling of differences and changes with longitudinal data. Annual Review of Psychology, 60(1), 577–605. \doi{10.1146/annurev.psych.60.110707.163612}.
 #' 
 #' Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36.
-#' \url{http://www.jstatsoft.org/v48/i02/}.
-#' @examples # Simulate data from bivariate LCS model parameters 
+#' \doi{10.18637/jss.v048.i02}.
+#' @examples # Simulate data from bivariate LCSM parameters 
 #' sim_bi_lcsm(timepoints = 12, 
 #'             na_x_pct = .05,
 #'             na_y_pct = .1,
@@ -266,7 +269,8 @@ sim_bi_lcsm <- function(timepoints,
                         model_x, model_x_param = NULL, 
                         model_y, model_y_param = NULL, 
                         coupling, coupling_param = NULL,
-                        sample.nobs = 500, na_x_pct = 0, na_y_pct = 0, ...,
+                        sample.nobs = 500, na_x_pct = 0, na_y_pct = 0, seed = NULL,
+                        ...,
                         var_x = "x", var_y = "y", change_letter_x = "g", change_letter_y = "j", 
                         return_lavaan_syntax = FALSE
                         ){
@@ -317,7 +321,7 @@ sim_bi_lcsm <- function(timepoints,
     
     # Test if all labels have been specified
     if (base::all(check_labels) == TRUE){
-      base::message("All parameter estimates for the LCS model have been specified in the argument 'model_param'.")
+      base::message("All parameter estimates for the LCSM have been specified in the argument 'model_param'.")
     } else if (base::all(check_labels) == FALSE){
       
       missing_labels <- labels[base::which(!check_labels)]
@@ -326,7 +330,7 @@ sim_bi_lcsm <- function(timepoints,
       
       missing_labels_02 <- stringr::str_c(missing_labels_01, sep = "", collapse = "\n")
       
-      base::warning(paste0("The following parameters are specified in LCS model but no parameter estimates have been entered in 'model_param':\n", missing_labels_02), call. = FALSE)
+      base::warning(paste0("The following parameters are specified in the LCSM but no parameter estimates have been entered in 'model_param':\n", missing_labels_02), call. = FALSE)
     }
     
     estimates <- model_param
@@ -362,7 +366,7 @@ sim_bi_lcsm <- function(timepoints,
                                          group.label = paste("G", 1:ngroups, sep = ""), 
                                          skewness = 0, 
                                          kurtosis = 0, 
-                                         seed = NULL, 
+                                         seed = seed,
                                          empirical = FALSE, 
                                          return.type = "data.frame",
                                          return.fit = FALSE,
@@ -388,7 +392,7 @@ sim_bi_lcsm <- function(timepoints,
   
   # X
   sim_data_x_model_ids <- sim_data_model_ids %>%
-    dplyr::select(id, var_names_x)
+    dplyr::select(id, dplyr::all_of(var_names_x))
   
   sim_data_x_model_ids_nas <- sim_data_x_model_ids %>%
     tidyr::gather(vars, value, -id) %>%
@@ -400,7 +404,7 @@ sim_bi_lcsm <- function(timepoints,
   
   # Y
   sim_data_y_model_ids <- sim_data_model_ids %>%
-    dplyr::select(id, var_names_y)
+    dplyr::select(id, dplyr::all_of(var_names_y))
   
   sim_data_y_model_ids_nas <- sim_data_y_model_ids %>%
     tidyr::gather(vars, value, -id) %>%
@@ -418,6 +422,7 @@ sim_bi_lcsm <- function(timepoints,
   if (return_lavaan_syntax == FALSE){
     # Return simulated data
     return(sim_data_xy_model_ids_nas)
+    
   } else if (return_lavaan_syntax == TRUE){
 
       return(model_estimates)
